/*
*  This file is an example of views applied to AdventureWorksDW database 
*  for the article describing best practices published at http://www.sqlbi.com/articles/data-import-bestices-in-power-bi/ 
*
*  It has been tested on AdventureWorksDW2012, but it should work also with other versions of the same database
*  You can download AdventureWorksDW2012 SQL Server database from: http://msftdbprodsamples.codeplex.com/releases/view/55330
*
*/
USE [AdventureWorksDW2012]
GO

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE SCHEMA BestPractice
GO

CREATE VIEW [BestPractice].[Products] AS
    SELECT
        ProductKey              = ProductKey,
		[Product Code]          = ProductAlternateKey,
        [Product Name]          = EnglishProductName,
        Cost                    = StandardCost,
        Color                   = Color,
        [List Price]            = ListPrice,
        [Product Model]         = ModelName,
        Category                = EnglishProductCategoryName,
        Subcategory             = EnglishProductSubcategoryName,
	    ScdStatus               = Status,
        ScdStartDate            = StartDate

    FROM
        dbo.DimProduct

        LEFT JOIN 

        dbo.DimProductSubcategory WITH (NOLOCK)
        ON dbo.DimProduct.ProductSubcategoryKey = dbo.DimProductSubcategory.ProductSubcategoryKey
        LEFT  JOIN dbo.DimProductCategory WITH (NOLOCK)
        ON dbo.DimProductSubcategory.ProductCategoryKey = dbo.DimProductCategory.ProductCategoryKey
GO

CREATE VIEW [BestPractice].[Date] AS
    SELECT
        DateKey     = DateKey,
        [Date]           = FullDateAlternateKey,
        [Month]          = EnglishMonthName,
        [Month Year]     = EnglishMonthName + ' ' + CAST ( CalendarYear AS VARCHAR ( 4 ) ),
        MonthNumber      = MonthNumberOfYear,
        MonthYearNumber  = MonthNumberOfYear + CalendarYear * 12 - 1,
        Year             = CalendarYear
    FROM
        dbo.DimDate

GO


CREATE VIEW [BestPractice].[Customers]
AS
SELECT
    CustomerKey = CustomerKey,
    Name = FirstName + ' ' + LastName,
    [Marital Status] = CASE MaritalStatus
                      WHEN 'M' THEN 'Married'
                      WHEN 'S' THEN 'Single'
                      ELSE '<unknown>'
                    END,
    Gender = CASE Gender
               WHEN 'M' THEN 'Male'
               WHEN 'F' THEN 'Female'
               ELSE '<unknown>'
             END,
    Education = EnglishEducation,
    Occupation = EnglishOccupation,
    [House Owner] = CASE HouseOwnerFlag
                   WHEN 0 THEN 'NOT House Owner'
                   WHEN 1 THEN 'House Owner'
                   ELSE '<unknown>'
                 END,
    City = g.[City],
    [Country Code] = g.[CountryRegionCode],
    [Country Name] = g.[EnglishCountryRegionName],
    [Postal Code] = g.[PostalCode]
FROM
    dbo.DimCustomer c WITH ( NOLOCK )
LEFT JOIN [dbo].[DimGeography] g
    ON c.GeographyKey = g.GeographyKey


GO

CREATE VIEW [BestPractice].[Sales] AS
    SELECT     
        ProductKey,
        OrderDate,
		CustomerKey,
        [Line Quantity] = OrderQuantity,
		[Unit Price] = UnitPrice
    FROM dbo.FactInternetSales WITH (NOLOCK)


GO

